@@ -30,7 +30,7 @@ import fnmatch
 USAGE = """
 \t%prog [OPTIONS] [file1 file2 ... fileN]
 """
-VERSION = '1.9.2'
+VERSION = '1.10.0'
 
 misspellings = {}
 exclude_lines = set()
@@ -38,6 +38,7 @@ options = None
 file_opener = None
 quiet_level = 0
 encodings = ['utf-8', 'iso-8859-1']
+word_regex = re.compile(r"[\w\-']+")
 # Users might want to link this file into /usr/local/bin, so we resolve the
 # symbolic link path to the real path if necessary.
 default_dictionary = os.path.join(os.path.dirname(os.path.realpath(__file__)),
@@ -215,13 +216,20 @@ def parse_options(args):
                       action='store_true', default=False,
                       help='write changes in place if possible')
     parser.add_option('-D', '--dictionary',
-                      action='store', metavar='FILE',
-                      default=default_dictionary,
+                      action='append', metavar='FILE',
                       help='Custom dictionary file that contains spelling '
-                           'corrections. If this flag is not specified '
-                           'then default dictionary "%s" is used.' %
+                           'corrections. If this flag is not specified or '
+                           'equals "-" then default dictionary "%s" is used. '
+                           'This option can be specified multiple times.' %
                       default_dictionary)
-
+    parser.add_option('-r', '--regex',
+                      action='store', type='string',
+                      help='Regular expression which is used to find words. '
+                           'By default any alphanumeric character, the '
+                           'underscore, the hyphen, and the apostrophe is '
+                           'used to build words (i.e. %s). This option cannot '
+                           'be specified together with the write-changes '
+                           'functionality. ' % word_regex.pattern)
     parser.add_option('-s', '--summary',
                       action='store_true', default=False,
                       help='print summary of fixes')
@@ -405,7 +413,6 @@ def parse_file(filename, colors, summary):
             return 0
 
     bad_count = 0
-    rx = re.compile(r"[\w\-']+")
     for i, line in enumerate(lines):
         if line in exclude_lines:
             continue
@@ -413,14 +420,14 @@ def parse_file(filename, colors, summary):
         fixed_words = set()
         asked_for = set()
 
-        for word in rx.findall(line):
+        for word in word_regex.findall(line):
             lword = word.lower()
             if lword in misspellings:
                 fix = misspellings[lword].fix
                 fixword = fix_case(word, misspellings[lword].data)
 
                 if options.interactive and lword not in asked_for:
-                    fix, fixword = ask_for_word_fix(lines[i - 1], word,
+                    fix, fixword = ask_for_word_fix(lines[i], word,
                                                     misspellings[lword],
                                                     options.interactive)
                     asked_for.add(lword)
@@ -443,7 +450,7 @@ def parse_file(filename, colors, summary):
                     continue
 
                 cfilename = "%s%s%s" % (colors.FILE, filename, colors.DISABLE)
-                cline = "%s%d%s" % (colors.FILE, i, colors.DISABLE)
+                cline = "%s%d%s" % (colors.FILE, i + 1, colors.DISABLE)
                 cwrongword = "%s%s%s" % (colors.WWORD, word, colors.DISABLE)
                 crightword = "%s%s%s" % (colors.FWORD, fixword, colors.DISABLE)
 
@@ -500,14 +507,29 @@ def main(*args):
 
     options, args, parser = parse_options(args)
 
-    if not os.path.exists(options.dictionary):
-        print(default_dictionary)
-        print('ERROR: cannot find dictionary file:\n%s' % options.dictionary,
-              file=sys.stderr)
-        parser.print_help()
-        return 1
+    if options.regex:
+        if options.write_changes:
+            parser.error('--write-changes cannot be used together with '
+                         '--regex')
+        global word_regex
+        try:
+            word_regex = re.compile(options.regex)
+        except re.error as err:
+            print('ERROR: invalid regular expression "%s" (%s)' %
+                  (options.regex, err), file=sys.stderr)
+            parser.print_help()
+            return 1
 
-    build_dict(options.dictionary)
+    dictionaries = options.dictionary or [default_dictionary]
+    for dictionary in dictionaries:
+        if dictionary is "-":
+            dictionary = default_dictionary
+        if not os.path.exists(dictionary):
+            print('ERROR: cannot find dictionary file: %s' % dictionary,
+                  file=sys.stderr)
+            parser.print_help()
+            return 1
+        build_dict(dictionary)
     colors = TermColors()
     if not options.colors:
         colors.disable()
